"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
// Local imports
const buildCSPHeaders_1 = __importDefault(require("../src/lib/buildCSPHeaders"));
const CSP_1 = require("../src/models/CSP");
describe('buildCSPHeaders', () => {
    function testCSPWithConfig(testName, config) {
        test(testName, () => {
            var _a, _b, _c;
            const builtCSPHeaders = (0, buildCSPHeaders_1.default)(config);
            const expectedCSP = Object.assign(Object.assign({}, CSP_1.CSP_REQUIRED_DIRECTIVE_DEFAULTS), ((config === null || config === void 0 ? void 0 : config.contentSecurityPolicy) || {}));
            if ((config === null || config === void 0 ? void 0 : config.isDev) && config.contentSecurityPolicy !== false) {
                if (!((_a = config.contentSecurityPolicy) === null || _a === void 0 ? void 0 : _a['connect-src'])) {
                    expectedCSP['connect-src'] = '\'self\' webpack://*';
                }
                if (!((_b = config.contentSecurityPolicy) === null || _b === void 0 ? void 0 : _b['script-src'])) {
                    expectedCSP['script-src'] = '\'self\' \'unsafe-eval\'';
                }
                if (!((_c = config.contentSecurityPolicy) === null || _c === void 0 ? void 0 : _c['style-src'])) {
                    expectedCSP['style-src'] = '\'self\' \'unsafe-inline\'';
                }
            }
            expect(builtCSPHeaders).toBeInstanceOf(Array);
            expect(builtCSPHeaders).toHaveLength(3);
            builtCSPHeaders.forEach(header => {
                Object.entries(expectedCSP).forEach(([key, value]) => {
                    expect(header.value).toContain(`${key} ${value};`);
                });
            });
        });
    }
    describe('production mode', () => {
        testCSPWithConfig('with defaults');
        testCSPWithConfig('with customized config', {
            contentSecurityPolicy: {
                'base-uri': 'https://trezy.com',
            },
        });
    });
    describe('development mode', () => {
        testCSPWithConfig('with defaults', {
            isDev: true,
        });
        testCSPWithConfig('with customized config', {
            contentSecurityPolicy: {
                'base-uri': 'https://trezy.com',
            },
            isDev: true,
        });
    });
});
